"""
Performance monitoring and analytics system for Kaizen AI framework.

This module provides real-time performance monitoring with:
- MetricsCollector: Lightweight metric collection (<1ms overhead)
- AnalyticsAggregator: Real-time windowed statistics
- AlertManager: Threshold-based alerting
- PerformanceDashboard: Web-based visualization
"""

from .metrics_collector import MetricsCollector
from .analytics_aggregator import AnalyticsAggregator, TimeWindow
from .alert_manager import (
    AlertManager,
    NotificationChannel,
    EmailNotificationChannel,
    SlackNotificationChannel,
    WebhookNotificationChannel
)
from .dashboard import PerformanceDashboard, app

__all__ = [
    'MetricsCollector',
    'AnalyticsAggregator',
    'TimeWindow',
    'AlertManager',
    'NotificationChannel',
    'EmailNotificationChannel',
    'SlackNotificationChannel',
    'WebhookNotificationChannel',
    'PerformanceDashboard',
    'app',
]
